@@ -6,11 +6,11 @@ import sys
 import fies
 from sout import sout
 # 形式変換 (yaml -> equid) [yaml_style_to_equid]
-from parts import yaml_style_to_equid as y2e
+from .parts import yaml_style_to_equid as y2e
 # 2次計画問題の行列を定義するjsコードに変換 [to_qp_mat_js.py]
-from parts import to_qp_mat_js as tqmj
+from .parts import to_qp_mat_js as tqmj
 # クライアント側jsを生成 (2次計画法でHTMLの動的な割り付けを実施) [gen_compiled_rcss.py]
-from parts import gen_compiled_rcss as gcr
+from .parts import gen_compiled_rcss as gcr
 
 # ファイル名拡張子の変更
 def ext_rep(org_filename, new_ext):
